@@ -1,7 +1,7 @@
 
 import sys, os
 # import torch
-import numpy as np
+# import numpy as np
 # import torch.multiprocessing as mp
 import multiprocessing as mp
 import itertools
