@@ -16,22 +16,27 @@ class InitWall:
 
 class Singleton(object):
     _instance = None
+    
+    def __init_subclass__(cls, **kwargs):
+        super().__init_subclass__(**kwargs)
+        cls._instance = None
+    
     def __new__(cls, *args, **kwargs):
         if not cls._instance:
             cls._instance = super().__new__(cls)
         return cls._instance
 
 
-class InitSingleton(Singleton):
-    _instance_initialized = False
-    
-    def __init__(self, *args, **kwargs):
-        if not self.__class__._instance_initialized:
-            self.__class__._instance_initialized = True
-            self.__init_singleton__(*args, **kwargs)
-    
-    def __init_singleton__(self, *args, **kwargs):
-        pass
+# class InitSingleton(Singleton):
+#     _instance_initialized = False
+#
+#     def __init__(self, *args, **kwargs):
+#         if not self.__class__._instance_initialized:
+#             self.__class__._instance_initialized = True
+#             self.__init_singleton__(*args, **kwargs)
+#
+#     def __init_singleton__(self, *args, **kwargs):
+#         pass
 
 
 
